Open source projects are “living.” Contributions in the form of issues and pull requests are welcomed and encouraged. When you contribute, you explicitly say you are part of the community and abide by its Code of Conduct.

# The Code

At Intuit, we foster a kind, respectful, harassment-free cooperative community. Our open source community works to:

- Be kind and respectful;
- Act as a global community;
- Conduct ourselves professionally.

As members of this community, we will not tolerate behaviors including, but not limited to:

- Violent threats or language;
- Discriminatory or derogatory jokes or language;
- Public or private harassment of any kind;
- Other conduct considered inappropriate in a professional setting.

## Reporting Concerns

If you see someone violating the Code of Conduct please email TechOpenSource@intuit.com

## Scope

This code of conduct applies to:

All repos and communities for Intuit-managed projects, whether or not the text is included in a Intuit-managed project’s repository;

Individuals or teams representing projects in official capacity, such as via official social media channels or at in-person meetups.

## Attribution

This Code of Conduct is partly inspired by and based on those of Amazon, CocoaPods, GitHub, Microsoft, thoughtbot, and on the Contributor Covenant version 1.4.1.